==> zio-aws-codestar_2.13-5.17.123.2-sources.jar: zio/aws/codestar/model/ListProjectsResponse.scala <==
package zio.aws.codestar.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.codestar.model.primitives.PaginationToken
import scala.jdk.CollectionConverters._
final case class ListProjectsResponse(
    projects: Iterable[zio.aws.codestar.model.ProjectSummary],
    nextToken: Option[PaginationToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codestar.model.ListProjectsResponse = {
    import ListProjectsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codestar.model.ListProjectsResponse
      .builder()
      .projects(projects.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.codestar.model.ListProjectsResponse.ReadOnly =
    zio.aws.codestar.model.ListProjectsResponse.wrap(buildAwsValue())
}
object ListProjectsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codestar.model.ListProjectsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codestar.model.ListProjectsResponse =
      zio.aws.codestar.model.ListProjectsResponse(
        projects.map { item =>
          item.asEditable
        },
        nextToken.map(value => value)
      )
    def projects: List[zio.aws.codestar.model.ProjectSummary.ReadOnly]
    def nextToken: Option[PaginationToken]
    def getProjects: ZIO[Any, Nothing, List[
      zio.aws.codestar.model.ProjectSummary.ReadOnly
    ]] = ZIO.succeed(projects)
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codestar.model.ListProjectsResponse
  ) extends zio.aws.codestar.model.ListProjectsResponse.ReadOnly {
    override val projects
        : List[zio.aws.codestar.model.ProjectSummary.ReadOnly] = impl
      .projects()
      .asScala
      .map { item =>
        zio.aws.codestar.model.ProjectSummary.wrap(item)
      }
      .toList
    override val nextToken: Option[PaginationToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.codestar.model.primitives.PaginationToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.codestar.model.ListProjectsResponse
  ): zio.aws.codestar.model.ListProjectsResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-codestar_2.13-6.20.103.1-sources.jar: zio/aws/codestar/model/ListProjectsResponse.scala <==
package zio.aws.codestar.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.codestar.model.primitives.PaginationToken
import scala.jdk.CollectionConverters._
final case class ListProjectsResponse(
    projects: Iterable[zio.aws.codestar.model.ProjectSummary],
    nextToken: Optional[PaginationToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codestar.model.ListProjectsResponse = {
    import ListProjectsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codestar.model.ListProjectsResponse
      .builder()
      .projects(projects.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.codestar.model.ListProjectsResponse.ReadOnly =
    zio.aws.codestar.model.ListProjectsResponse.wrap(buildAwsValue())
}
object ListProjectsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codestar.model.ListProjectsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codestar.model.ListProjectsResponse =
      zio.aws.codestar.model.ListProjectsResponse(
        projects.map { item =>
          item.asEditable
        },
        nextToken.map(value => value)
      )
    def projects: List[zio.aws.codestar.model.ProjectSummary.ReadOnly]
    def nextToken: Optional[PaginationToken]
    def getProjects: ZIO[Any, Nothing, List[
      zio.aws.codestar.model.ProjectSummary.ReadOnly
    ]] = ZIO.succeed(projects)
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codestar.model.ListProjectsResponse
  ) extends zio.aws.codestar.model.ListProjectsResponse.ReadOnly {
    override val projects
        : List[zio.aws.codestar.model.ProjectSummary.ReadOnly] = impl
      .projects()
      .asScala
      .map { item =>
        zio.aws.codestar.model.ProjectSummary.wrap(item)
      }
      .toList
    override val nextToken: Optional[PaginationToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.codestar.model.primitives.PaginationToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.codestar.model.ListProjectsResponse
  ): zio.aws.codestar.model.ListProjectsResponse.ReadOnly = new Wrapper(impl)
}
